"""Init file of LyzrRag."""

from pathlib import Path

import logging
from logging import NullHandler
from typing import Callable, Optional

# import global eval handler
from .callbacks.global_handlers import set_global_handler

# response
from .core.response.schema import Response
from .data_structs.struct_type import IndexStructType

# embeddings
from .embeddings import OpenAIEmbedding

# indices
# loading
from .indices import (
    ComposableGraph,
    DocumentSummaryIndex,
    GPTDocumentSummaryIndex,
    GPTKeywordTableIndex,
    GPTKnowledgeGraphIndex,
    GPTListIndex,
    GPTRAKEKeywordTableIndex,
    GPTSimpleKeywordTableIndex,
    GPTTreeIndex,
    GPTVectorStoreIndex,
    KeywordTableIndex,
    KnowledgeGraphIndex,
    ListIndex,
    RAKEKeywordTableIndex,
    SimpleKeywordTableIndex,
    SummaryIndex,
    TreeIndex,
    VectorStoreIndex,
    load_graph_from_storage,
    load_index_from_storage,
    load_indices_from_storage,
)

# structured
from .indices.common.struct_store.base import SQLDocumentContextBuilder

# prompt helper
from .indices.prompt_helper import PromptHelper
from .llm_predictor import LLMPredictor

# token predictor
from .llm_predictor.mock import MockLLMPredictor

# prompts
from .prompts import (
    BasePromptTemplate,
    ChatPromptTemplate,
    # backwards compatibility
    Prompt,
    PromptTemplate,
    SelectorPromptTemplate,
)
from .readers import (
    SimpleDirectoryReader,
    download_loader,
)

# Response Synthesizer
from .response_synthesizers.factory import get_response_synthesizer
from .schema import Document, QueryBundle
from .service_context import (
    ServiceContext,
    set_global_service_context,
)

# storage
from .storage.storage_context import StorageContext
from .token_counter.mock_embed_model import MockEmbedding

# sql wrapper
from .utilities.sql_wrapper import SQLDatabase

# global tokenizer
from .utils import get_tokenizer, set_global_tokenizer

# best practices for library logging:
# https://docs.python.org/3/howto/logging.html#configuring-logging-for-a-library
logging.getLogger(__name__).addHandler(NullHandler())

__all__ = [
    "StorageContext",
    "ServiceContext",
    "ComposableGraph",
    # indices
    "SummaryIndex",
    "VectorStoreIndex",
    "SimpleKeywordTableIndex",
    "KeywordTableIndex",
    "RAKEKeywordTableIndex",
    "TreeIndex",
    "DocumentSummaryIndex",
    "KnowledgeGraphIndex",
    # indices - legacy names
    "GPTKeywordTableIndex",
    "GPTKnowledgeGraphIndex",
    "GPTSimpleKeywordTableIndex",
    "GPTRAKEKeywordTableIndex",
    "GPTListIndex",
    "ListIndex",
    "GPTTreeIndex",
    "GPTVectorStoreIndex",
    "GPTDocumentSummaryIndex",
    "Prompt",
    "PromptTemplate",
    "BasePromptTemplate",
    "ChatPromptTemplate",
    "SelectorPromptTemplate",
    "OpenAIEmbedding",
    "SummaryPrompt",
    "TreeInsertPrompt",
    "TreeSelectPrompt",
    "TreeSelectMultiplePrompt",
    "RefinePrompt",
    "QuestionAnswerPrompt",
    "KeywordExtractPrompt",
    "QueryKeywordExtractPrompt",
    "Response",
    "Document",
    "SimpleDirectoryReader",
    "LLMPredictor",
    "MockLLMPredictor",
    "VellumPredictor",
    "VellumPromptRegistry",
    "MockEmbedding",
    "SQLDatabase",
    "SQLDocumentContextBuilder",
    "SQLContextBuilder",
    "PromptHelper",
    "IndexStructType",
    "download_loader",
    "load_graph_from_storage",
    "load_index_from_storage",
    "load_indices_from_storage",
    "QueryBundle",
    "get_response_synthesizer",
    "set_global_service_context",
    "set_global_handler",
    "set_global_tokenizer",
    "get_tokenizer",
]

# eval global toggle
from .callbacks.base_handler import BaseCallbackHandler

global_handler: Optional[BaseCallbackHandler] = None

# NOTE: keep for backwards compatibility
SQLContextBuilder = SQLDocumentContextBuilder

# global service context for ServiceContext.from_defaults()
global_service_context: Optional[ServiceContext] = None

# global tokenizer
global_tokenizer: Optional[Callable[[str], list]] = None



from setuptools import setup, find_packages

setup(
    name="lyzr-rag",
    version="0.1.2",
    author="Lyzr",
    author_email="contact@lyzr.ai",
    description="Lyzr Core",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://lyzr.ai",
    project_urls={
        "Documentation": "https://docs.lyzr.ai/",
        "Source": "https://github.com/LyzrCore/lyzr_rag",
    },
    packages=find_packages(include=["lyzr_rag"]),
    python_requires=">=3.8.1,<4.0",
    install_requires=[
        "SQLAlchemy[asyncio]>=1.4.49",
        "dataclasses-json",
        "deprecated>=1.2.9.3",
        "fsspec>=2023.5.0",
        "httpx",
        "langchain>=0.0.303; extra == 'langchain'",
        "nest-asyncio==1.5.8",
        "nltk==3.8.1",
        "numpy",
        "openai>=1.1.0",
        "pandas",
        "tenacity>=8.2.0,<9.0.0",
        "tiktoken>=0.3.3",
        "typing-extensions>=4.5.0",
        "typing-inspect>=0.8.0",
        "requests>=2.31.0",  # Pin to avoid CVE-2023-32681 in requests 2.3 to 2.30
        "gradientai>=1.4.0; extra == 'gradientai'",
        "asyncpg==0.28.0; extra == 'postgres'",
        "pgvector==0.1.0; extra == 'postgres'",
        "optimum[onnxruntime]==1.13.2; extra == 'local_models'",
        "sentencepiece==0.1.99; extra == 'local_models'",
        "transformers[torch]==4.33.1; extra == 'local_models'",
        "guidance==0.0.64; extra == 'query_tools'",
        "lm-format-enforcer==0.4.3; extra == 'query_tools'",
        "jsonpath-ng==1.6.0; extra == 'query_tools'",
        "rank-bm25==0.2.2; extra == 'query_tools'",
        "scikit-learn; extra == 'query_tools'",
        "spacy==3.7.1; extra == 'query_tools'",
        "aiohttp==3.8.6",
        "networkx>=3.0",
        "psycopg2-binary==2.9.9; extra == 'postgres'",
        "dirtyjson==1.0.8",
    ],
    license="MIT",
    include_package_data=True,
)
